import { assignableWindow } from '../utils/globals';
import { logger } from '../utils/logger';
import { loadScript } from '../utils';
import Config from '../config';
import { isUndefined } from '../utils/type-utils';
var LOGGER_PREFIX = '[TRACING-HEADERS]';
var TracingHeaders = /** @class */ (function () {
    function TracingHeaders(instance) {
        var _this = this;
        this.instance = instance;
        this._restoreXHRPatch = undefined;
        this._restoreFetchPatch = undefined;
        this._startCapturing = function () {
            // NB: we can assert sessionManager is present only because we've checked previously
            if (isUndefined(_this._restoreXHRPatch)) {
                assignableWindow.postHogTracingHeadersPatchFns._patchXHR(_this.instance.sessionManager);
            }
            if (isUndefined(_this._restoreFetchPatch)) {
                assignableWindow.postHogTracingHeadersPatchFns._patchFetch(_this.instance.sessionManager);
            }
        };
    }
    TracingHeaders.prototype._loadScript = function (cb) {
        if (assignableWindow.postHogTracingHeadersPatchFns) {
            // already loaded
            cb();
        }
        loadScript(this.instance.requestRouter.endpointFor('assets', "/static/tracing-headers.js?v=".concat(Config.LIB_VERSION)), function (err) {
            if (err) {
                logger.error(LOGGER_PREFIX + ' failed to load script', err);
            }
            cb();
        });
    };
    TracingHeaders.prototype.startIfEnabledOrStop = function () {
        var _a, _b;
        if (this.instance.config.__add_tracing_headers) {
            this._loadScript(this._startCapturing);
        }
        else {
            (_a = this._restoreXHRPatch) === null || _a === void 0 ? void 0 : _a.call(this);
            (_b = this._restoreFetchPatch) === null || _b === void 0 ? void 0 : _b.call(this);
            // we don't want to call these twice so we reset them
            this._restoreXHRPatch = undefined;
            this._restoreFetchPatch = undefined;
        }
    };
    return TracingHeaders;
}());
export { TracingHeaders };
//# sourceMappingURL=tracing-headers.js.map